@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # * Authors:
 #       * Arezki Feth <f.a@majerti.fr>;
 #       * Miotte Julien <j.m@majerti.fr>;
@@ -33,6 +32,7 @@ class BaseSqlaInspector(object):
 
         Force the list of model attributes to use
     """
+
     def __init__(self, model, excludes=(), includes=(), **kw):
         self.inspector = inspect(model)
         self.excludes = excludes
@@ -48,15 +48,21 @@ class BaseSqlaInspector(object):
         """
         Return only the columns
         """
-        return [prop for prop in self.get_sorted_columns() \
-                if isinstance(prop, ColumnProperty)]
+        return [
+            prop
+            for prop in self.get_sorted_columns()
+            if isinstance(prop, ColumnProperty)
+        ]
 
     def get_relationships_only(self):
         """
         Return only the relationships
         """
-        return [prop for prop in self.get_sorted_columns() \
-                if isinstance(prop, RelationshipProperty)]
+        return [
+            prop
+            for prop in self.get_sorted_columns()
+            if isinstance(prop, RelationshipProperty)
+        ]
 
     @staticmethod
     def get_info_field(prop):
@@ -76,6 +82,7 @@ class Registry(dict):
     """
     A registry used to store sqla columns <-> datas association
     """
+
     def add_item(self, sqla_col_type, item, key_specific=None):
         """
         Add an item to the registry
@@ -95,10 +102,12 @@ class Registry(dict):
 
         return item
 
+
 class FormatterRegistry(Registry):
     """
     Registry specific to formatters
     """
+
     def add_formatter(self, sqla_col_type, formatter, key_specific=None):
         """
         Add a formatter to the registry
